import {environment} from "../../environments/environment";

export class Endpoints {

  // private static apiUrl: string = "http://localhost:86/fitness_web/customerapi/web/index.php?r=";
  private static apiUrl: string = environment.apiUrl;

  public static POST_USERS_AUTHENTICATE(){
    return `${this.apiUrl}login/login`;
  }

  public static POST_USER_PASSWORD_CHANGE(){
    return `${this.apiUrl}user/password-change`;
  }

  public static GET_EVENTS( ){
    return `${this.apiUrl}/events`;
  }

  public static GET_EVENT( id: number){
    return `${this.apiUrl}/event/event&id_event=${id}`;
  }


  public static POST_EVENT_REGISTRATIONS_REGISTER(id: number){
    return `${this.apiUrl}/event-registration/register&id_event=${id}`;
  }

  public static GET_EVENT_REGISTRATIONS_FIND(){
    return `${this.apiUrl}/event-registration/index`;
  }

  public static GET_REGISTRATION( id: number){
    return `${this.apiUrl}/event-registration/registration&id_registration=${id}`;
  }

  public static POST_EVENT_CANCEL( id: number){
    return `${this.apiUrl}/event/cancel&id_event=${id}`;
  }

  public static POST_EVENT_REGISTRATION_CANCEL( id: number){
    return `${this.apiUrl}/event-registration/cancel&idRegistration=${id}`;
  }

  public static GET_EVENT_TYPES(){
    return `${this.apiUrl}/event-type`;
  }


  public static GET_EVENTS_AVAILABLE(){
    return `${this.apiUrl}/event/available`;
  }

}
